@ECHO OFF
REM Possible command line switches:
REM
REM Paths have to end with "\"
REM
REM /b - will be automatically used as a base path, e.g.
REM pointing to your levels (or game) directory (G:\Battlefield 1942)
REM
REM /p - The pathname that you want to be parsed. This is put after the base pathname
REM      and also can replace b completely.
REM 
REM /f - The files you want to be parsed. Can include wildcards (e.g. Tx*.tga)
REM
REM /o - Where you want the converted files to be saved (default is same dir)
REM
REM /overwrite - Overwrite existing files (default is false, files will get a trailing "_")
REM
REM /forcewrite - Overwrite existing files (default is false, files will get a trailing "_")
REM
REM /q x - Quality setting, x can be 1234 (default is 3)
REM
REM /s - Silent: Tool runs silent and will close when done.
REM If first three are specified, the tool instantly parses: [Base pathname]\[pathname]\[filenames]
REM
REM Example: ddsconvert /b G:\bfdev /q2 - This launches interface, but sets a base path already. 
REM Useful for "WIP" stuff when the level name differs often.
REM 
REM Example: ddsconvert /p G:\bfdev\bf1942\levels\gazala\Textures /f Tx*.tga /q4 /s
REM This would run the whole folder quick&silent.

REM Init variables
SET b=
SET q=quality_production
SET p=
SET f=
SET s=FALSE
SET o=-outsamedir
SET overwrite=
SET forcewrite=
SET dxt=-dxt3

:switchcheck
IF '%1'=='/b'         GOTO setb
IF '%1'=='/p'         GOTO setp
IF '%1'=='/f'         GOTO setf
IF '%1'=='/q'         GOTO setq
IF '%1'=='/s'         GOTO sets
IF '%1'=='/o'         GOTO seto
IF '%1'=='/overwrite' GOTO setoverwrite
IF '%1'=='/forcewrite' GOTO set/forcewrite
GOTO :choice

:setb
SET b=%2
SHIFT
SHIFT
GOTO switchcheck

:setp
SET p=%2
SHIFT
SHIFT
GOTO switchcheck

:setf
SET f=%2
SHIFT
SHIFT
GOTO switchcheck

:setq
IF %2==4 SET q=quality_highest
IF %2==3 SET q=quality_production
IF %2==2 SET q=quality_normal
IF %2==1 SET q=quick
SHIFT
SHIFT
GOTO switchcheck

:sets
SET s=TRUE
SHIFT
GOTO switchcheck

:seto
SET o=-outdir %2
SHIFT
SHIFT
GOTO switchcheck

:setoverwrite
SET overwrite=-overwrite
SHIFT
GOTO switchcheck

:setforcewrite
SET forcewrite=-forcewrite
SHIFT
GOTO switchcheck

REM User interface
:choice

cls
IF DEFINED p (
 IF DEFINED f (
  GOTO parse
 )
)


ECHO --------------------------------------------------------------------
ECHO --------------------------------------------------------------------
ECHO ------------ Batch dds converter v1 MAIN MENU by Senshi ------------
ECHO --------------------------------------------------------------------
ECHO ---------------------- www.wargamer-project.de ---------------------
ECHO -------------------------- www.bfmods.com --------------------------
ECHO --------------------------------------------------------------------
ECHO Pick your desired action:
ECHO 1 - Parse with common BF42 folder structure:
ECHO     %b%bf1942\levels\MAPNAME
ECHO.
ECHO 2 - Parse with manual path
ECHO.
ECHO.
ECHO 3 - Quality settings
ECHO                       Current: %q%
ECHO.
ECHO 4 - Write settings
ECHO     Current settings:
IF DEFINED overwrite ECHO                       %overwrite%
IF DEFINED forcewrite ECHO                       %forcewrite%
ECHO                       Output dir:  %o%
ECHO.
ECHO 5 - Exit
ECHO --------------------------------------------------------------------

CHOICE /C 1234 /M "Choose your action"
IF ERRORLEVEL 5 GOTO EOF
IF ERRORLEVEL 4 GOTO choice_write
IF ERRORLEVEL 3 GOTO choice_qual
IF ERRORLEVEL 2 GOTO start
IF ERRORLEVEL 1 GOTO startEd42

:choice_write
cls
ECHO --------------------------------------------------------------------
ECHO --------------------------------------------------------------------
ECHO Battlefield Batch dds converter v1 WRITE SETTINGS
ECHO --------------------------------------------------------------------
ECHO --------------------------------------------------------------------
ECHO Which setting do you want to change?
ECHO 1 - Overwrite (toggle) - currently: %overwrite%
ECHO     Should existing files be overwritten (default is no)
ECHO.
ECHO 2 - Forcewrite (toggle) - currently: %forcewrite%
ECHO     Should read-only files be overwritten (default is no)
ECHO.
ECHO 3 - Pick an output directory - currently: %o%
ECHO     Default is same directory
ECHO.
ECHO 4 - Return to main menu
ECHO --------------------------------------------------------------------
CHOICE /C 1234 /M "Choose your action"
IF ERRORLEVEL 4 GOTO choice
IF ERRORLEVEL 3 GOTO pickdir
IF ERRORLEVEL 2 GOTO toggleforcewrite
IF ERRORLEVEL 1 GOTO toggleoverwrite

:toggleforcewrite
IF NOT DEFINED forcewrite SET forcewrite=-forcewrite &GOTO choice_write
IF DEFINED forcewrite SET forcewrite=&GOTO choice_write

:toggleoverwrite
IF NOT DEFINED overwrite SET overwrite=-overwrite &GOTO choice_write
IF DEFINED overwrite SET overwrite=&GOTO choice_write

:pickdir
ECHO --------------------------------------------------------------------
SET/p o_temp=Output directory:
IF NOT DEFINED o_temp SET o=-outsamedir &GOTO choice_write
SET o=-outdir %o_temp%
SET o_temp=
GOTO choice_write



:choice_qual
cls
ECHO --------------------------------------------------------------------
ECHO --------------------------------------------------------------------
ECHO Battlefield Batch dds converter v1 QUALITY SETTINGS
ECHO --------------------------------------------------------------------
ECHO --------------------------------------------------------------------
ECHO 1 - Choose compression algorithm (speed, not size)
ECHO     Currently: %q%
ECHO.
ECHO 2 - Choose DXT quality type (size, not speed)
ECHO     Currently: %dxt%
ECHO.
ECHO 3 - Return to main menu
ECHO --------------------------------------------------------------------

CHOICE /C 123 /M "Choose your action"
IF ERRORLEVEL 3 GOTO choice
IF ERRORLEVEL 2 GOTO choice_qual_DXT
IF ERRORLEVEL 1 GOTO choice_qual_comp


:choice_qual_comp
cls
ECHO --------------------------------------------------------------------
ECHO --------------------------------------------------------------------
ECHO Battlefield Batch dds converter v1 COMPRESSION SETTINGS
ECHO --------------------------------------------------------------------
ECHO --------------------------------------------------------------------
ECHO Pick your desired compression algorithm (currently %q%)
ECHO 1 - Quick
ECHO.
ECHO 2 - Normal
ECHO.
ECHO 3 - Production (default)
ECHO.
ECHO 4 - Maximum (slow)
ECHO --------------------------------------------------------------------

CHOICE /C 1234 /M "Choose your action"
IF ERRORLEVEL 4 SET q=quality_highest &GOTO choice_qual
IF ERRORLEVEL 3 SET q=quality_production &GOTO choice_qual
IF ERRORLEVEL 2 SET q=quality_normal &GOTO choice_qual
IF ERRORLEVEL 1 SET q=quick &GOTO choice_qual


:choice_qual_dxt
cls
ECHO --------------------------------------------------------------------
ECHO --------------------------------------------------------------------
ECHO Battlefield Batch dds converter v1 DXT SETTINGS
ECHO --------------------------------------------------------------------
ECHO --------------------------------------------------------------------
ECHO Pick your desired DXT type (currently %dxt%)
ECHO For most scenarios, the first five options are sufficient!
ECHO 1  - DXT1c    RGB   4bpp no alpha
ECHO 2  - DXT1a   ARGB   4bpp 1bit-alpha
ECHO 3  - DXT3    ARGB   8bpp explicit alpha
ECHO 4  - DXT5    ARGB   8bpp interpolated alpha
ECHO 5  - DXT5NM    XY   8bpp Normal Maps using DXT5
ECHO 6  - ARGB   16bpp   uncompressed 1:5:5:5
ECHO 7  -  RGB   16bpp   uncompressed 4:4:4:4
ECHO 8  -  RGB   16bpp   uncompressed 5:6:5
ECHO 9  - ARGB   32bpp   uncompressed 8:8:8:8
ECHO 10  - XRGB  32bpp   uncompressed 0:8:8:8
ECHO 11 -  RGB   16bpp   uncompressed 0:5:5:5
ECHO 12 -  RGB    8bpp   paletted 8 bit (256 colors)
ECHO 13 - ARGB    8bpp   paletted 8 bit (256 colors with alpha)
ECHO 14 -  RGB    4bpp   paletted 4 bit (16 colors)
ECHO 15 - ARGB    4bpp   paletted 4 bit (16 colors with alpha)
ECHO 16 -    A    8bpp   8 bit alpha channel
ECHO 17 -   XY    8bpp   normal map format
ECHO 18 -   VU   16bpp   EMBM format (8, bit two component signed)
ECHO 19 -   VU   32bpp   EMBM format (16 bit, two component signed)
ECHO 20 -   AL   16bpp   8 bit alpha channel, 8 bit luminance
ECHO 21 - ABGR  128bpp   fp32 four channels (A32B32G32R32F)
ECHO 22 -    R   32bpp   fp32 one channel (R32F)
ECHO 23 - ABGR   64bpp   fp16 four channels (A16B16G16R16F)
ECHO 24 -   GB   32bpp   16 bit in, two component
ECHO 25 -   GR   32bpp   16 bit float, two components
ECHO 26 (or q or quit)   Returns to quality menu
ECHO --------------------------------------------------------------------

SET/P dxt_choice=Choose your desired compression: 


IF %dxt_choice%==q                       GOTO choice_qual
IF %dxt_choice%==quit                    GOTO choice_qual
IF %dxt_choice%==26                      GOTO choice_qual
IF %dxt_choice%==25  SET dxt=-g16r16f   &GOTO choice_qual
IF %dxt_choice%==24  SET dxt=-g16r16    &GOTO choice_qual
IF %dxt_choice%==23  SET dxt=-fp16x4    &GOTO choice_qual
IF %dxt_choice%==22  SET dxt=-fp32      &GOTO choice_qual
IF %dxt_choice%==21  SET dxt=-fp32x4    &GOTO choice_qual
IF %dxt_choice%==20  SET dxt=-A8L8      &GOTO choice_qual
IF %dxt_choice%==19  SET dxt=-v16u16    &GOTO choice_qual
IF %dxt_choice%==18  SET dxt=-v8u8      &GOTO choice_qual
IF %dxt_choice%==17  SET dxt=-cxv8u8    &GOTO choice_qual
IF %dxt_choice%==16  SET dxt=-a8        &GOTO choice_qual
IF %dxt_choice%==15  SET dxt=-p4a       &GOTO choice_qual
IF %dxt_choice%==14  SET dxt=-p4c       &GOTO choice_qual
IF %dxt_choice%==13  SET dxt=-p8a       &GOTO choice_qual
IF %dxt_choice%==12  SET dxt=-p8c       &GOTO choice_qual
IF %dxt_choice%==11  SET dxt=-u555      &GOTO choice_qual
IF %dxt_choice%==10  SET dxt=-u888      &GOTO choice_qual
IF %dxt_choice%==9   SET dxt=-u8888     &GOTO choice_qual
IF %dxt_choice%==8   SET dxt=-u565      &GOTO choice_qual
IF %dxt_choice%==7   SET dxt=-u4444     &GOTO choice_qual
IF %dxt_choice%==6   SET dxt=-u1555     &GOTO choice_qual
IF %dxt_choice%==5   SET dxt=-dxt5nm    &GOTO choice_qual
IF %dxt_choice%==4   SET dxt=-dxt5      &GOTO choice_qual
IF %dxt_choice%==3   SET dxt=-dxt3      &GOTO choice_qual
IF %dxt_choice%==2   SET dxt=-dxt1a     &GOTO choice_qual
IF %dxt_choice%==1   SET dxt=-dxt1c     &GOTO choice_qual
GOTO choice_qual_dxt


:startEd42
ECHO Paths have to end with "\"!
IF NOT DEFINED p SET/p p=Input level folder name(type q to return):
IF NOT DEFINED p GOTO startEd42
IF %p%==q SET p=&GOTO choice
IF NOT EXIST %b%bf1942\levels\%p% (
 ECHO Directory %b%bf1942\levels\%p% does not exist! 
 SET p=&ECHO.
 GOTO startEd42
)
ECHO.
ECHO --------------------------------------------------------------------
ECHO The filename may contain wildcards.
ECHO The filename also can specify a filetype.
ECHO Example: Tx*.tga - This would convert all terrain texture files
ECHO --------------------------------------------------------------------
ECHO.
IF NOT DEFINED f set/p f=Input filename (q to return):
IF NOT DEFINED f SET f=*
IF %f%==q SET f=""&GOTO choice

echo Will convert all %f% files in: %b%bf1942\levels\%p%Textures\
CHOICE /C YNC /M "Is that correct?"
IF ERRORLEVEL 3 GOTO choice
IF ERRORLEVEL 2 GOTO startEd42
IF ERRORLEVEL 1 GOTO parseEd42

:parseEd42
IF %s%==FALSE ECHO nvDXT.exe -%q% -file %b%bf1942\levels\%p%Textures\%f% %o% %overwrite% %forcewrite% & ECHO.
nvDXT.exe -%q% -file %b%bf1942\levels\%p%Textures\%f% %o% %overwrite% %forcewrite%
ECHO.
ECHO --------------------------------------------------------------------
ECHO --------------------- Batch conversion complete --------------------
ECHO --------------------------------------------------------------------
ECHO.
IF %s%==FALSE @PAUSE
GOTO eof



:start
ECHO Paths have to end with "\"!
IF NOT DEFINED p SET/p p=Input level folder name(type q to return):
IF NOT DEFINED p GOTO start
IF %p%==q SET p=&GOTO choice
IF NOT EXIST %b%%p% (
 ECHO Directory %b%%p% does not exist! 
 SET p=&ECHO.
 GOTO start
)
ECHO.
ECHO --------------------------------------------------------------------
ECHO The filename may contain wildcards.
ECHO The filename also can specify a filetype.
ECHO Example: Tx*.tga - This would convert all terrain texture files
ECHO --------------------------------------------------------------------
ECHO.
IF NOT DEFINED f set/p f=Input filename (q to return):
IF NOT DEFINED f SET f=*
IF %f%==q SET f="" &GOTO choice

echo Will convert all %f% files in: %b%%p%
CHOICE /C YNC /M "Is that correct?"
IF ERRORLEVEL 3 GOTO choice
IF ERRORLEVEL 2 GOTO start
IF ERRORLEVEL 1 GOTO parse

:parse
IF %s%==FALSE ECHO nvDXT.exe -%q% -file %b%%p%%f% %o% %overwrite% %forcewrite% & ECHO.
nvDXT.exe -%q% -file %b%%p%%f% %o% %overwrite% %forcewrite%
ECHO.
ECHO --------------------------------------------------------------------
ECHO --------------------- Batch conversion complete --------------------
ECHO --------------------------------------------------------------------
ECHO.
IF %s%==FALSE @PAUSE

:EOF